@@ -13,7 +13,7 @@ Visit <https://github.com/jwodder/outgoing> or <https://outgoing.rtfd.io> for
 more information.
 """
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 __author__ = "John Thorvald Wodder II"
 __author_email__ = "outgoing@varonathe.org"
 __license__ = "MIT"
@@ -29,6 +29,7 @@ from .config import (
 )
 from .core import (
     DEFAULT_CONFIG_SECTION,
+    Sender,
     from_config_file,
     from_dict,
     get_default_configpath,
@@ -57,6 +58,7 @@ __all__ = [
     "OpenClosable",
     "Password",
     "Path",
+    "Sender",
     "StandardPassword",
     "from_config_file",
     "from_dict",
